@@ -39,7 +39,7 @@ class Client:
             "y": y
         }
         if self.get_limit == 0:
-            time.sleep(self.get_timeout + 0.2)
+            time.sleep(self.get_timeout + 1)
 
         with self.__http.get(self.base + "/get_pixel", headers = self.headers, params=data) as resp:
             data = resp.json()
@@ -66,7 +66,7 @@ class Client:
         if scale <=0:
             raise TypeError("Scale must be a positive integer")
         if self.gets_limit == 0:
-            time.sleep(self.gets_timeout+ 0.2)
+            time.sleep(self.gets_timeout+ 1)
         with self.__http.get(self.base + "/get_pixels", headers=self.headers) as resp:
             stream = bytes(resp.content)
             headers = resp.headers
@@ -118,7 +118,7 @@ class Client:
             "rgb": hex(color)[2:].upper()
         }
         if self.post_limit == 0:
-            time.sleep(self.post_timeout + 0.2)
+            time.sleep(self.post_timeout + 1)
         with self.__http.post(self.base + "/set_pixel", headers=self.headers, json=data) as resp:
             headers = resp.headers
             print(headers)
